You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@iceberg.apache.org by et...@apache.org on 2023/05/04 12:23:01 UTC

[iceberg] branch master updated: API: Update Javadoc for listTables and listViews (#7336)

This is an automated email from the ASF dual-hosted git repository.

etudenhoefner pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/iceberg.git


The following commit(s) were added to refs/heads/master by this push:
     new f0149a5860 API: Update Javadoc for listTables and listViews (#7336)
f0149a5860 is described below

commit f0149a5860efe3f78d7cb07b81b4e1910b438020
Author: Ajantha Bhat <aj...@gmail.com>
AuthorDate: Thu May 4 17:52:55 2023 +0530

    API: Update Javadoc for listTables and listViews (#7336)
---
 api/src/main/java/org/apache/iceberg/catalog/Catalog.java     | 4 ++--
 api/src/main/java/org/apache/iceberg/catalog/ViewCatalog.java | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/api/src/main/java/org/apache/iceberg/catalog/Catalog.java b/api/src/main/java/org/apache/iceberg/catalog/Catalog.java
index b458589a34..de4009886c 100644
--- a/api/src/main/java/org/apache/iceberg/catalog/Catalog.java
+++ b/api/src/main/java/org/apache/iceberg/catalog/Catalog.java
@@ -26,8 +26,8 @@ import org.apache.iceberg.SortOrder;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.Transaction;
 import org.apache.iceberg.exceptions.AlreadyExistsException;
+import org.apache.iceberg.exceptions.NoSuchNamespaceException;
 import org.apache.iceberg.exceptions.NoSuchTableException;
-import org.apache.iceberg.exceptions.NotFoundException;
 
 /** A Catalog API for table create, drop, and load operations. */
 public interface Catalog {
@@ -46,7 +46,7 @@ public interface Catalog {
    *
    * @param namespace a namespace
    * @return a list of identifiers for tables
    * @throws NotFoundException if the namespace is not found
    */
   List<TableIdentifier> listTables(Namespace namespace);
 
@@ -46,7 +46,7 @@ public interface Catalog {
    * @param namespace a namespace
    * @return a list of identifiers for tables
-   * @throws NotFoundException if the namespace is not found
+   * @throws NoSuchNamespaceException if the namespace is not found
    */
   List<TableIdentifier> listTables(Namespace namespace);
diff --git a/api/src/main/java/org/apache/iceberg/catalog/ViewCatalog.java b/api/src/main/java/org/apache/iceberg/catalog/ViewCatalog.java
index 2a89466ca3..df118e2596 100644
--- a/api/src/main/java/org/apache/iceberg/catalog/ViewCatalog.java
+++ b/api/src/main/java/org/apache/iceberg/catalog/ViewCatalog.java
@@ -21,8 +21,8 @@ package org.apache.iceberg.catalog;
 import java.util.List;
 import java.util.Map;
 import org.apache.iceberg.exceptions.AlreadyExistsException;
+import org.apache.iceberg.exceptions.NoSuchNamespaceException;
 import org.apache.iceberg.exceptions.NoSuchViewException;
-import org.apache.iceberg.exceptions.NotFoundException;
 import org.apache.iceberg.view.View;
 import org.apache.iceberg.view.ViewBuilder;
 
@@ -41,7 +41,7 @@ public interface ViewCatalog {
    *
    * @param namespace a namespace
    * @return a list of identifiers for views
    * @throws NotFoundException if the namespace is not found
    */
   List<TableIdentifier> listViews(Namespace namespace);
@@ -41,7 +41,7 @@ public interface ViewCatalog {
    * @param namespace a namespace
    * @return a list of identifiers for views
-   * @throws NotFoundException if the namespace is not found
+   * @throws NoSuchNamespaceException if the namespace is not found
    */
   List<TableIdentifier> listViews(Namespace namespace);